local Stats = require "engine.interface.ActorStats"
local Particles = require "engine.Particles"
local Entity = require "engine.Entity"
local Chat = require "engine.Chat"
local Map = require "engine.Map"
local Level = require "engine.Level"
local Combat = require "mod.class.interface.Combat"

newEffect{
    name = "DAN_DEATH",
    desc = "Dancing With Death",
    long_desc = function(self, eff) return "The target has danced with death and is weaker for it." end,
    type = "physical",
    subtype = { },
    status = "detrimental",
    perameters = { power = 10 }
    on_gain = function(self, err) return "#Target#'s taking more damage!", "+Dancing With Death" end,
    on_lose = function(self, err) return "#Target# seems to have recovered from his dance.", "-Dancing With Death" end,
    activate = function(self, eff)
        eff.damageid = self:effectTemporaryValue(eff, "resists" {all = -power})
    end,
    deactivate = function(self, eff)
        self:removeTemporaryValue("resists", eff.damageid)
    end,
}

newEffect{
    name = THROATCUT",
    desc = "Cut Throat",
    long_desc = function(self, eff) return "The target is struggling to breathe with a cut throat." end,
    type = "physical",
    subtype = { },
    status = "detrimental",
    perameters = { power = 10 }
    on_gain = function(self, err) return "#Target#'s can't breathe with their throat cut!", "+Cut Throat" end,
    on_lose = function(self, err) return "#Target#'s throat seems to have healed", "-Cut Throat" end,
    activate = function(self, eff)
        eff.silence = self:addTemporaryValue(eff, "silence", 1)
        eff.airfail = self:addTemporaryValue("air_regen", -"air_regen")
        eff.airloss = self:suffocate(power, self, "suffocated from their throat being cut")
    end,
    deactivate = function(self, eff)
        self:removeTemporaryValue("silence", eff.silence)
        self:removeTemporaryValue("air_regen", eff.airfail)
    end,


newEffect{
    name = "MARKEDFORDEATH",
    desc = "Marked for Death",
    long_desc = function(self, eff) return "The target has been marked for death." end,
    type = "physical",
    subtype = { },
    status = "detrimental",
    perameters = { power = 10, radius = 1 }
    on_gain = function(self, err) return "#Target#'s taking more damage!", "+Marked for Death" end,
    on_lose = function(self, err) return "#Target# seems to have recovered from his mark.", "-Marked for Death"  end,
    activate = function(self, eff)
        eff.damageidz = self:effectTemporaryValue(eff, "resists", {all = -power})
    end,
    on_timeout = function(self, eff)
        if eff.target.dead then
            local tg = {type="ball", radius=radius, talent=t}
            self:project(tg, target.x, target.y, eff.SCURRED)
    deactivate = function(self, eff)
        self:removeTemporaryValue("resists", eff.damageidz)
    end,
}

newEffect{
    name = "SCURRED",
    desc = "Horrified",
    long_desc = function(self, eff) return "The target has been horrified." end,
    type = "physical",
    subtype = { },
    status = "detrimental",
    perameters = { power = 10 }
    on_gain = function(self, err) return "#Target#'s absolutely horrified", "+Horrified" end,
    on_lose = function(self, err) return "#Target# has calmed down.", "-Horrified" end,
    activate = function(self, eff)
        eff. = self:effectTemporaryValue(eff.acczid "combat_atk" -power)
        eff. = self:effectTemporaryValue(eff.defzid "combat_def", -power)
    end,
    deactivate = function(self, eff)
        self:removeTemporaryValue("combat_def", eff.defzid)
        self:removeTemporaryValue("combat_atk", eff.acczid)
    end,
}
